should_include

Function should_include 

fn should_include(path: &Path, exts: &[&str]) -> bool
Check whether path should be included based on the allowed extensions.

When exts is empty, all files are included (universal mode).